using System;
using System.Collections.Generic;
using System.ComponentModel;
using System.Data;
using System.Drawing;
using System.Text;
using System.Windows.Forms;
using InfiniTec.Exchange;
using System.Threading;
using InfiniTec.Threading;

namespace ExampleApplication.Example
{
    [View("Search items (Async)")]
    public partial class SearchItemsAsync: SearchItems
    {
        Searcher searcher;

        public SearchItemsAsync()
        {
            InitializeComponent();
        }

        protected override void DoSearch()
        {
            searcher = CreateSearcher();

            searcher.ProgressChanged += searcher_ProgressChanged;
            searcher.Completed += searcher_Completed;

            searcher.FindAsync();
        }

        void searcher_Completed(object sender, SearchCompletedEventArgs e)
        {
            Invoke((ThreadStart) delegate
            {
                if (e.Error != null)
                {
                    ViewManager.ShowException(e.Error);
                    return;
                }
                lbProgress.Items.Add("Finished. Cancelled: " + e.Cancelled);

                if (e.Items != null)
                {
                    DisplayResults(e.Items);
                }
            });
        }

        void searcher_ProgressChanged(object sender, SearchProgressChangedEventArgs e)
        {
            string s;

            Invoke((ThreadStart) delegate
            {
                s = e.RequestStatus.ToString();
                if (e.Range != null)
                {
                    s += string.Format(" Range: {0}-{1}", e.Range.From, e.Range.To);
                }

                lbProgress.Items.Add(s);

                if (e.Items != null)
                {
                    foreach (Item item in e.Items)
                    {
                        lbProgress.Items.Add("    " + item.Url.ToString());
                    }
                }
            });
        }
    }
}

